<!-- warning: Please don't edit this file. It was automatically generated. -->

# winui3-Microsoft.UI.Xaml.Media.Media3D

Windows Runtime (WinRT) APIs for for the `winui3-Microsoft.UI.Xaml.Media.Media3D` namespace.

This package provides the `winui3.microsoft.ui.xaml.media.media3d` module.
